@@ -28,7 +28,8 @@ ssri <- ssri %>% dplyr::mutate(class= dplyr::case_when(grepl("pram", agent) ~ "P
 
 alldfs <- list(triptans, psoriasis90.noplac, osteopain, psoriasis75, ssri, ssri.noplac, gout)
 datanams <- c("triptans", "psoriasis90.noplac", "osteopain", "psoriasis75", "ssri", "ssri.noplac", "gout")
-
+#alldfs <- list(ssri, ssri.noplac)
+#datanams <- c("ssri", "ssri.noplac")
 
 
 for (dat in seq_along(alldfs)) {
@@ -62,7 +63,7 @@ for (dat in seq_along(alldfs)) {
       skip_on_cran()
 
       n.iter=500
-      pd <- "pv"
+      pD <- FALSE
 
       if ("stansd" %in% names(network$data.ab)) {
         sdscale <- TRUE
@@ -71,16 +72,16 @@ for (dat in seq_along(alldfs)) {
       }
 
       # NMA
-      nma <- suppressWarnings(nma.run(network, method="random", pd=pd, n.iter=500, sdscale=sdscale))
+      nma <- suppressWarnings(nma.run(network, method="random", pD=pD, n.iter=500, sdscale=sdscale))
       expect_error(plot(nma), NA)
 
       # Nonparm MBNMA
       if (grepl("noplac", datanam)) {
         expect_error(mbnma.run(network, fun=dnonparam(), method="common",
-                               pd=pd, n.iter=n.iter, sdscale=sdscale), "must currently include placebo")
+                               pD=pD, n.iter=n.iter, sdscale=sdscale), "must currently include placebo")
       } else {
         mbnma <- mbnma.run(network, fun=dnonparam(), method="common",
-                           pd=pd, n.iter=n.iter, sdscale=sdscale)
+                           pD=pD, n.iter=n.iter, sdscale=sdscale)
         expect_error(plot(mbnma), NA)
         expect_error(summary(mbnma), "Cannot use")
         expect_error(predict(mbnma), "does not work with non-parametric")
@@ -90,10 +91,9 @@ for (dat in seq_along(alldfs)) {
 
       # Single parameter DR functions
       result <- mbnma.run(network, fun=dpoly(degree=1), method="common",
-                          pd="plugin", n.iter=n.iter, sdscale=sdscale)
+                          pD=TRUE, n.iter=n.iter, sdscale=sdscale)
       expect_equal(class(result), c("mbnma", "rjags"))
       expect_equal("beta.1" %in% result$parameters.to.save, TRUE)
-      expect_equal(result$model.arg$pd, "plugin")
       expect_error(plot(result), NA)
       expect_error(rank(result), NA)
       expect_error(predict(result), NA)
@@ -102,7 +102,7 @@ for (dat in seq_along(alldfs)) {
 
 
       result <- mbnma.run(network, fun=dexp(), method="random",
-                          pd="pd.kl", n.iter=n.iter, sdscale=sdscale)
+                          pD=TRUE, n.iter=n.iter, sdscale=sdscale)
       expect_equal(class(result), c("mbnma", "rjags"))
       expect_equal("sd" %in% result$parameters.to.save, TRUE)
       expect_error(plot(result), NA)
@@ -115,7 +115,7 @@ for (dat in seq_along(alldfs)) {
 
       if ("class" %in% names(dataset)) {
         result <- mbnma.run(netclass, fun=dexp(), method="common",
-                                           pd="popt", class.effect = list(emax="random"), n.iter=n.iter,
+                                           pD=TRUE, class.effect = list(emax="random"), n.iter=n.iter,
                                            sdscale=sdscale)
         expect_equal(class(result), c("mbnma", "rjags"))
         expect_equal("EMAX" %in% result$parameters.to.save, TRUE)
@@ -129,7 +129,7 @@ for (dat in seq_along(alldfs)) {
         expect_error(get.relative(result), NA)
 
         expect_warning(mbnma.run(netclass, fun=dexp(p.expon=TRUE), method="common", cor=TRUE,
-                                           pd="popt", class.effect = list(emax="random"), n.iter=n.iter,
+                                           pD=TRUE, class.effect = list(emax="random"), n.iter=n.iter,
                                            sdscale=sdscale), "Class effects cannot be modelled with correlation")
 
       }
@@ -138,7 +138,7 @@ for (dat in seq_along(alldfs)) {
 
       # Two parameter DR functions
       result <- mbnma.run(network, fun=demax(), method="common",
-                          n.iter=n.iter, pd=pd, sdscale=sdscale)
+                          n.iter=n.iter, pD=pD, sdscale=sdscale)
       expect_equal(all(c("emax", "ed50") %in% result$parameters.to.save), TRUE)
       expect_error(plot(result), NA)
       expect_error(rank(result), NA)
@@ -149,7 +149,7 @@ for (dat in seq_along(alldfs)) {
 
 
       result <- mbnma.run(network, fun=demax(ed50="common"), method="random",
-                          n.iter=n.iter, pd=pd, sdscale=sdscale)
+                          n.iter=n.iter, pD=pD, sdscale=sdscale)
       expect_equal("sd" %in% result$parameters.to.save, TRUE)
       expect_equal("ed50" %in% rownames(result$BUGSoutput$summary), TRUE)
       expect_error(plot(result), NA)
@@ -163,9 +163,9 @@ for (dat in seq_along(alldfs)) {
                                class.effect=list(fakeparam="common"), sdscale=sdscale), "corresponding to dose-response parameters")
 
         expect_warning(mbnma.run(netclass, fun=demax(p.expon=TRUE), method="random", cor=TRUE,
-                                 class.effect=list(ed50="common"), n.iter=n.iter, pd=pd, sdscale=sdscale))
+                                 class.effect=list(ed50="common"), n.iter=n.iter, pD=pD, sdscale=sdscale))
         result <- suppressWarnings(mbnma.run(netclass, fun=demax(), method="random",
-                                             class.effect=list(ed50="common"), n.iter=n.iter, pd=pd, sdscale=sdscale))
+                                             class.effect=list(ed50="common"), n.iter=n.iter, pD=pD, sdscale=sdscale))
         expect_equal(all(c("emax", "ED50", "ed50", "sd") %in% result$parameters.to.save), TRUE)
         expect_error(plot(result), NA)
         expect_error(rank(result), NA)
@@ -176,7 +176,7 @@ for (dat in seq_along(alldfs)) {
 
 
       result <- mbnma.run(network, fun=demax(ed50="random"), method="common",
-                          n.iter=n.iter, pd=pd, sdscale=sdscale)
+                          n.iter=n.iter, pD=pD, sdscale=sdscale)
       expect_equal(all(c("emax", "ed50", "sd.ed50") %in% result$parameters.to.save), TRUE)
       expect_error(plot(result), NA)
       expect_error(rank(result), NA)
@@ -186,7 +186,7 @@ for (dat in seq_along(alldfs)) {
 
       # Three parameter DR function
       result <- tryCatch(mbnma.run(network, fun=demax(emax="rel", ed50="random", hill="common"),
-                                   method="random", n.iter=n.iter, pd=pd, priors = list(hill="dunif(0.1,3)"),
+                                   method="random", n.iter=n.iter, pD=pD, priors = list(hill="dunif(0.1,3)"),
                                    sdscale=sdscale), error=function(e){})
 
       if (!is.null(result)) {
@@ -198,7 +198,7 @@ for (dat in seq_along(alldfs)) {
       }
 
       result <- mbnma.run(network, fun=dspline(type="ns", knots=3, beta.1="rel", beta.2="random", beta.3="common"),
-                          method="random", n.iter=n.iter, pd=pd, sdscale=sdscale)
+                          method="random", n.iter=n.iter, pD=pD, sdscale=sdscale)
       expect_equal(all(c("beta.1", "beta.2", "sd.beta.2", "sd", "beta.3") %in% result$parameters.to.save), TRUE)
       expect_equal(any(grepl("spline", result$model.arg$jagscode)), TRUE)
       expect_error(plot(result), NA)
@@ -211,7 +211,7 @@ for (dat in seq_along(alldfs)) {
 
       result <- tryCatch(mbnma.run(network, fun=demax(ed50="random", hill=1.2),
                           parameters.to.save = "psi", sdscale=sdscale,
-                          method="random", n.iter=n.iter, pd=pd), error=function(e){})
+                          method="random", n.iter=n.iter, pD=pD), error=function(e){})
 
       if (!is.null(result)) {
         expect_equal("psi" %in% result$parameters.to.save, TRUE)
@@ -228,7 +228,7 @@ for (dat in seq_along(alldfs)) {
 
       # Splines and polynomials
       result <- mbnma.run(network, fun=dspline(type="bs", knots=2, beta.1="common", beta.2 = "rel", beta.3="random"),
-                          n.iter=n.iter, pd=pd, sdscale=sdscale)
+                          n.iter=n.iter, pD=pD, sdscale=sdscale)
       expect_equal(all(c("beta.1", "beta.2", "sd.beta.3", "beta.3") %in% result$parameters.to.save), TRUE)
       expect_equal(all(c("sd") %in% result$parameters.to.save), FALSE)
       expect_error(plot(result), NA)
@@ -237,7 +237,7 @@ for (dat in seq_along(alldfs)) {
       expect_error(suppressWarnings(summary(result)), NA)
 
       result <- mbnma.run(network, fun=dspline(type="ns", knots=c(0.2,0.5), beta.1="common", beta.2 = "rel", beta.3="random"),
-                          n.iter=n.iter, pd=pd, sdscale=sdscale)
+                          n.iter=n.iter, pD=pD, sdscale=sdscale)
       expect_equal(all(c("beta.1", "beta.2") %in% result$parameters.to.save), TRUE)
       expect_equal(all(c("sd", "beta.3") %in% result$parameters.to.save), FALSE)
       expect_error(plot(result), NA)
@@ -249,7 +249,7 @@ for (dat in seq_along(alldfs)) {
 
       if (!datanam %in% "osteopain") {
         result <- mbnma.run(network, fun=dpoly(degree=3, beta.1="common", beta.2 = "rel", beta.3="random"),
-                            method="random", n.iter=n.iter, pd=pd, sdscale=sdscale)
+                            method="random", n.iter=n.iter, pD=pD, sdscale=sdscale)
         expect_equal(all(c("beta.1", "beta.2", "sd.beta.3", "beta.3", "sd") %in% result$parameters.to.save), TRUE)
         expect_error(plot(result), NA)
         expect_error(rank(result), NA)
@@ -262,38 +262,38 @@ for (dat in seq_along(alldfs)) {
       expect_equal(result$model.arg$omega, NULL)
 
       result <- mbnma.run(network, fun=dpoly(degree=3, beta.1="rel", beta.2 = "rel", beta.3="random"),
-                          method="random", n.iter=n.iter, pd=pd, sdscale=sdscale, cor = TRUE)
+                          method="random", n.iter=n.iter, pD=pD, sdscale=sdscale, cor = TRUE)
       expect_equal("inv.R" %in% names(result$model.arg$priors), TRUE)
       expect_equal(ncol(result$model.arg$omega), 2)
       expect_error(get.relative(result), NA)
 
 
       omega <- matrix(c(10,2,2,10), byrow = TRUE, ncol=2)
-      result <- mbnma.run(network, fun=demax(p.expon=TRUE), omega=omega, n.iter=n.iter, pd=pd, sdscale=sdscale, cor=TRUE)
+      result <- mbnma.run(network, fun=demax(p.expon=TRUE), omega=omega, n.iter=n.iter, pD=pD, sdscale=sdscale, cor=TRUE)
       expect_equal(ncol(result$model.arg$omega), 2)
       expect_equal(result$model.arg$omega[1,1], omega[1,1])
 
-      expect_error(mbnma.run(network, fun=demax(), omega=omega, n.iter=n.iter, pd=pd, sdscale=sdscale, cor=TRUE),
+      expect_error(mbnma.run(network, fun=demax(), omega=omega, n.iter=n.iter, pD=pD, sdscale=sdscale, cor=TRUE),
                    "cannot be modelled with truncated parameters")
 
       omega <- matrix(c(10,4,2,10), byrow = TRUE, ncol=2)
-      expect_error(mbnma.run(network, fun=demax(), omega=omega, n.iter=n.iter, pd=pd, cor=TRUE,
+      expect_error(mbnma.run(network, fun=demax(), omega=omega, n.iter=n.iter, pD=pD, cor=TRUE,
                              sdscale=sdscale), "omega must be")
 
-      result <- mbnma.run(network, fun=demax(), cor=FALSE, n.iter=n.iter, pd=pd, sdscale=sdscale)
+      result <- mbnma.run(network, fun=demax(), cor=FALSE, n.iter=n.iter, pD=pD, sdscale=sdscale)
       expect_equal("inv.R" %in% names(result$model.arg$priors), FALSE)
 
 
       # Test UME
       result <- mbnma.run(network, fun=dpoly(degree=3, beta.1="random", beta.2 = "rel", beta.3="rel"),
-                          method="random", n.iter=n.iter, pd=pd, UME=TRUE, sdscale=sdscale)
+                          method="random", n.iter=n.iter, pD=pD, UME=TRUE, sdscale=sdscale)
       expect_equal(all(c("beta.1", "beta.2", "sd.beta.1", "beta.3", "sd") %in% result$parameters.to.save), TRUE)
       expect_equal(any(grepl("beta\\.2\\[2,1\\]", rownames(result$BUGSoutput$summary))), TRUE)
       expect_equal(any(grepl("beta\\.3\\[2,1\\]", rownames(result$BUGSoutput$summary))), TRUE)
       expect_equal(any(grepl("beta\\.1\\[2,1\\]", rownames(result$BUGSoutput$summary))), FALSE)
 
       result <- mbnma.run(network, fun=dspline(knots=c(0.1, 0.3), type="ls"),
-                          n.iter=n.iter, pd=pd, UME=TRUE, sdscale=sdscale)
+                          n.iter=n.iter, pD=pD, UME=TRUE, sdscale=sdscale)
       expect_equal(any(grepl("beta\\.2\\[2,1\\]", rownames(result$BUGSoutput$summary))), TRUE)
       expect_equal(any(grepl("beta\\.3\\[2,1\\]", rownames(result$BUGSoutput$summary))), TRUE)
       expect_equal(any(grepl("beta\\.1\\[2,1\\]", rownames(result$BUGSoutput$summary))), TRUE)
@@ -309,9 +309,9 @@ for (dat in seq_along(alldfs)) {
 
       # Link functions
       if (datanam %in% c("triptans", "psoriasis90", "ssri")) {
-        expect_error(mbnma.run(network, fun=demax(), link="probit", n.iter=n.iter, pd=pd,
+        expect_error(mbnma.run(network, fun=demax(), link="probit", n.iter=n.iter, pD=pD,
                                sdscale=sdscale), NA)
-        result <- mbnma.run(network, fun=dfpoly(degree=2), link="cloglog", n.iter=n.iter, pd=pd,
+        result <- mbnma.run(network, fun=dfpoly(degree=2), link="cloglog", n.iter=n.iter, pD=pD,
                             sdscale=sdscale)
         expect_equal(result$model.arg$link, "cloglog")
 
@@ -325,13 +325,13 @@ for (dat in seq_along(alldfs)) {
 
         if (datanam %in% "gout") {
           expect_error(mbnma.run(network, fun=dspline(knots=2, type="bs"), link="smd",
-                                 n.iter=n.iter, pd=pd, sdscale=sdscale), "must be included in data\\.ab")
+                                 n.iter=n.iter, pD=pD, sdscale=sdscale), "must be included in data\\.ab")
         } else if (datanam %in% "osteopain") {
           expect_error(mbnma.run(network, fun=dspline(knots=2, type="bs"), link="smd",
-                                 n.iter=n.iter, pd=pd, sdscale=sdscale), NA)
+                                 n.iter=n.iter, pD=pD, sdscale=sdscale), NA)
         }
 
-        result <- suppressWarnings(mbnma.run(network, fun=dexp(), link="log", n.iter=n.iter, pd=pd,
+        result <- suppressWarnings(mbnma.run(network, fun=dexp(), link="log", n.iter=n.iter, pD=pD,
                                              sdscale=sdscale))
         expect_equal(result$model.arg$link, "log")
 
@@ -351,22 +351,22 @@ for (dat in seq_along(alldfs)) {
         expect_error(mbnma.run(network, fun=dnonparam()), "must currently include placebo")
       } else {
         result <- mbnma.run(network, fun=dnonparam(direction = "decreasing"), method="random",
-                            n.iter=n.iter, pd=pd, sdscale=sdscale)
+                            n.iter=n.iter, pD=pD, sdscale=sdscale)
         expect_equal("d.1[1,1]" %in% rownames(result$BUGSoutput$summary), TRUE)
         expect_equal("sd" %in% result$parameters.to.save, TRUE)
         expect_error(summary(result))
 
-        expect_error(result <- mbnma.run(network, fun=dpoly(), method="fixed", n.iter=n.iter, pd=pd), "Must be element of set")
+        expect_error(result <- mbnma.run(network, fun=dpoly(), method="fixed", n.iter=n.iter, pD=pD), "Must be element of set")
       }
 
 
 
       # Changing priors
       result <- mbnma.run(network, fun=demax(p.expon=TRUE), method="random", cor=TRUE,
-                          n.iter=n.iter, pd=pd, sdscale=sdscale)
+                          n.iter=n.iter, pD=pD, sdscale=sdscale)
       prior <- list(sd="dunif(0,5)", inv.R="dwish(omega[,],5)")
       runprior <- mbnma.run(network, fun=demax(p.expon=TRUE), method="random", cor=TRUE,
-                            n.iter=n.iter, pd=pd, priors = prior, sdscale=sdscale)
+                            n.iter=n.iter, pD=pD, priors = prior, sdscale=sdscale)
       expect_equal(runprior$model.arg$priors$sd, prior$sd)
       expect_equal(runprior$model.arg$priors$inv.R, prior$inv.R)
       expect_equal(result$model.arg$priors$inv.R!=runprior$model.arg$priors$inv.R, TRUE)
@@ -383,7 +383,7 @@ for (dat in seq_along(alldfs)) {
         ))
 
       multifun <- mbnma.run(network, fun=mult,
-                            n.iter=n.iter, pd=pd, sdscale=sdscale)
+                            n.iter=n.iter, pD=pD, sdscale=sdscale)
       expect_equal(length(multifun$model.arg$fun$name)>1, TRUE)
       expect_equal(all(c("beta.1", "beta.2", "emax", "ed50", "emax.4") %in% multifun$parameters.to.save), TRUE)
       expect_error(get.relative(multifun), NA)
@@ -399,7 +399,7 @@ for (dat in seq_along(alldfs)) {
         ))
 
       multifun <- mbnma.run(network, fun=mult,
-                            method="random", n.iter=n.iter, pd=pd, sdscale=sdscale)
+                            method="random", n.iter=n.iter, pD=pD, sdscale=sdscale)
       expect_equal(all(c(paste0("beta.", c(1:6)), "power.1", "power.2", "sd") %in% multifun$parameters.to.save), TRUE)
       expect_equal(length(multifun$model.arg$fun$name)>1, TRUE)
 
@@ -441,7 +441,7 @@ for (dat in seq_along(alldfs)) {
         skip_on_cran()
 
         n.iter=500
-        pd <- "pv"
+        pD <- FALSE
 
         # Edit dataset
         ssri.reg <- ssri %>%
